local mod = ...



-- Job: Kitchen -------------------------------------------------------------------------------------
mod:registerAsset({
	DataType = "JOB",
	Id = "JOB_MONASTICLIFE_KITCHEN",
	JobName = "JOB_MONASTICLIFE_KITCHEN_NAME",
	JobDescription = "JOB_MONASTICLIFE_KITCHEN_DESC",
	IsLockedByDefault = true,
	DefaultBehavior = "BEHAVIOR_WORK",
	UseWorkplaceBehavior = true,
    ProductionDelay = 40, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		RightHandObject = {
			DataType = "HAND_OBJECT",
			Model = "PREFAB_TOOL_CHEESE_MAKER_SPOON"
		},
		WalkAnimation = "WALKING",
		IdleAnimation = "IDLE",
	},
})

mod:overrideAsset({
    Id = "MONK",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_MONASTICLIFE_KITCHEN",
    },
})

mod:overrideAsset({
    Id = "MONK_PRIOR",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_MONASTICLIFE_KITCHEN",
    },
})



-- Building Function: Kitchen: Recipe --------------------------------------------------------------------------------------------
local function registerRecipe(index, resource1, resource2, resource3)
    mod:registerAsset({
        DataType = "BUILDING_FUNCTION_WORKPLACE",
        Id = "BUILDING_FUNCTION_MONASTICLIFE_KITCHEN_RECIPE" .. index,
        Name = "BUILDING_FUNCTION_MONASTICLIFE_KITCHEN_RECIPE" .. index .. "_NAME",
        IsPrivate = true,
        WorkerCapacity = 2,
        RelatedJob = {
            Job = "JOB_MONASTICLIFE_KITCHEN",
            Behavior = "BEHAVIOR_WORK",
        },
        InputInventoryCapacity = {
            { Resource = resource1, Quantity = 20 },
            { Resource = resource2, Quantity = 20 },
            { Resource = resource3, Quantity = 20 },
        },
        ResourceListNeeded = {
            { Resource = resource1, Quantity = 1 },
            { Resource = resource2, Quantity = 1 },
            { Resource = resource3, Quantity = 1 },
        },
        ResourceProduced = {
            { Resource = "RESOURCE_MONASTERY_MEAL", Quantity = 5 },
        },
    })
end

registerRecipe(1, "MILK", "HONEY", "BREAD")
registerRecipe(2, "MILK", "HONEY", "RESOURCE_FRUIT")
registerRecipe(3, "MILK", "BV1_EGG", "BREAD")
registerRecipe(4, "RESOURCE_MUSHROOM", "RESOURCE_POULTRY", "HERBS")
registerRecipe(5, "RESOURCE_MUSHROOM", "RESOURCE_RABBIT", "HERBS")
registerRecipe(6, "RESOURCE_VEGETABLE", "FISH", "HERBS")


-- Building Function Assignable
mod:registerAsset({
    DataType = "BUILDING_FUNCTION_ASSIGNABLE",
    Id = "BUILDING_FUNCTION_MONASTICLIFE_KITCHEN",
	Name = "BUILDING_PART_MONASTICLIFE_KITCHEN_NAME",
	AuthorizedFunctionList = "FUNCTION_LIST_MONASTICLIFE_KITCHEN"
})

mod:registerAsset({
    DataType = "BUILDING_FUNCTION_LIST",
    Id = "FUNCTION_LIST_MONASTICLIFE_KITCHEN",
	AssetFunctionList = {
		"BUILDING_FUNCTION_MONASTICLIFE_KITCHEN_RECIPE1",
		"BUILDING_FUNCTION_MONASTICLIFE_KITCHEN_RECIPE2",
		"BUILDING_FUNCTION_MONASTICLIFE_KITCHEN_RECIPE3",
		"BUILDING_FUNCTION_MONASTICLIFE_KITCHEN_RECIPE4",
		"BUILDING_FUNCTION_MONASTICLIFE_KITCHEN_RECIPE5",
		"BUILDING_FUNCTION_MONASTICLIFE_KITCHEN_RECIPE6",
	},
})



-- Building Part: Kitchen -------------------------------------------------------------------------------------

-- Assets
mod:registerAssetId("models/Monastery1.fbx/Prefab/Kitchen.Part.001", "PREFAB_MONASTICLIFE_KITCHEN1" )
mod:registerAssetId("models/Monastery1.fbx/Prefab/Kitchen.Part.001.Constr", "PREFAB_MONASTICLIFE_KITCHEN1_CONSTR" )

-- Smoke Emitter -------------------------------------------------------------------------------------
mod:registerPrefabComponent("models/Monastery1.fbx/Prefab/Kitchen.Part.001/SmokeEmitter.001", {
	DataType = "COMP_PARTICLE_EMITTER",
	ParticleSystem = "PARTICLE_SYSTEM_HOUSING_SMOKE",
	IsPlaying = true,
	IsEmitting = true
})

mod:registerPrefabComponent("models/Monastery1.fbx/Prefab/Kitchen.Part.001/SmokeEmitter.001", {
	DataType = "COMP_PARTICLE_EMITTER_TOGGLE",
	Enabled = false
})

-- Attach Type
mod:registerPrefabComponent("PREFAB_MONASTICLIFE_KITCHEN1", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = "MAJOR"
})

-- Part
mod:registerAsset({
	DataType = "BUILDING_PART",
	Id = "BUILDING_PART_MONASTICLIFE_KITCHEN1",
	Name = "BUILDING_PART_MONASTICLIFE_KITCHEN_NAME",
	AssetBuildingFunction = "BUILDING_FUNCTION_MONASTICLIFE_KITCHEN",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
        CoreObjectPrefab = "PREFAB_MONASTICLIFE_KITCHEN1",
        MiniatureConfig = {
            ClipUnderGround = true,
            GroupHeight = 0,
            CameraPosition = { 0, 0, 0 },
            OrientationOffset = 0,
            CameraPitchOffset = 0.0
        },
	},
    IsOnlyAttached = true,
    ConstructionVisual = "PREFAB_MONASTICLIFE_KITCHEN1_CONSTR",
	BuildingZone = {
        ZoneEntryList = {
            {
                Polygon = polygon.createRectangle( {4.8, 7.0}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true }
			},
        },
	},
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD_COINS", Quantity = 20 }
        },
        UpkeepCost = {
            { Resource = "GOLD_COINS", Quantity = 10 }
        },
        ResourceNeededList = {
            {
                { Resource = "WOOD", Quantity = 4 },
                { Resource = "STONE", Quantity = 10 },
            },
            {
                { Resource = "POLISHED_STONE", Quantity = 20 },
                { Resource = "TOOL", Quantity = 6 },
            },
            {
                { Resource = "POLISHED_STONE", Quantity = 10 },
                { Resource = "PLANK", Quantity = 8 },
            },
        },
    },
})
