local mod = ...



-- Material -------------------------------------------------------------------------------------
for i = 1, 4 do
    mod:registerAssetId("models/Monastery1.fbx/Materials/Material.Tree" .. i, "MATERIAL_MONASTICLIFE_TREE" .. i)
    mod:overrideAsset({
        Id = "MATERIAL_MONASTICLIFE_TREE" .. i,
        HasAlphaTest = true,
    })
end

mod:registerAssetId("models/Monastery1.fbx/Materials/Material.Grass2", "MATERIAL_MONASTICLIFE_GRASS2")
mod:overrideAsset({
    Id = "MATERIAL_MONASTICLIFE_GRASS2",
    HasAlphaTest = true,
})

mod:registerAssetId("models/Monastery1.fbx/Materials/Material.Water1", "MATERIAL_MONASTICLIFE_WATER1")
mod:overrideAsset({
	Id = "MATERIAL_MONASTICLIFE_WATER1",
    RenderMode = "UNLIT",
    -- HasShadow = true,
})



-- Job: Fishing -------------------------------------------------------------------------------------
mod:registerAsset({
	DataType = "JOB",
	Id = "JOB_MONASTICLIFE_FISH",
	JobName = "JOB_MONASTICLIFE_FISH_NAME",
	JobDescription = "JOB_MONASTICLIFE_FISH_DESC",
	IsLockedByDefault = true,
	DefaultBehavior = "BEHAVIOR_WORK",
	UseWorkplaceBehavior = true,
    ProductionDelay = 40, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		RightHandObject = {
			DataType = "HAND_OBJECT",
			Model = "PREFAB_TOOL_FISHERMAN_ROD",
		},
        WalkAnimation = "WALKING",
		IdleAnimation = "FISHING_LOOP",
	},
})

mod:overrideAsset({
    Id = "MONK",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_MONASTICLIFE_FISH",
    },
})

mod:overrideAsset({
    Id = "MONK_PRIOR",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_MONASTICLIFE_FISH",
    },
})



-- Building Function: Fishing --------------------------------------------------------------------------------------------
mod:registerAsset({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "BUILDING_FUNCTION_MONASTICLIFE_FISH",
    Name = "BUILDING_FUNCTION_MONASTICLIFE_FISH_NAME",
    IsPrivate = true,
    WorkerCapacity = 1,
    RelatedJob = {
        Job = "JOB_MONASTICLIFE_FISH",
        Behavior = "BEHAVIOR_WORK",
    },
    InputInventoryCapacity = {
    },
    ResourceListNeeded = {
    },
    ResourceProduced = {
        { Resource = "FISH", Quantity = 1 },
    },
})



-- Building Part: Fisherman Spot -------------------------------------------------------------------------------------
mod:registerAssetId("models/Monastery1.fbx/Prefab/Fisher.Part.001", "PREFAB_MONASTICLIFE_FISHER1" )

mod:registerAsset({
	DataType = "BUILDING_PART",
	Id = "BUILDING_PART_MONASTICLIFE_FISHER1",
	Name = "BUILDING_PART_MONASTICLIFE_POND_NAME",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_MONASTICLIFE_FISHER1",
	},
    AssetBuildingFunction = "BUILDING_FUNCTION_MONASTICLIFE_FISH",
})



-- Building Part: Pond 1 -------------------------------------------------------------------------------------
mod:registerAssetId("models/Monastery1.fbx/Prefab/Pond.Part.001", "PREFAB_MONASTICLIFE_POND1" )
mod:configurePrefabFlagList("PREFAB_MONASTICLIFE_POND1", { "PLATFORM" })

-- Assemblage
mod:registerAsset({
	DataType = "BUILDING_PART",
	Id = "BUILDING_PART_MONASTICLIFE_POND1_ASSEMBLAGE",
	Name = "BUILDING_PART_MONASTICLIFE_POND_NAME",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_ASSEMBLAGE",
		CoreRandomBuildingPartList = { "PREFAB_MONASTICLIFE_POND1" },
		MandatoryBuildingPartList = {
			{ BuildingPart = "BUILDING_PART_MONASTICLIFE_FISHER1", OptionalAttachNodeString = "Attach_Major.005" },
			{ BuildingPart = "BUILDING_PART_MONASTICLIFE_FISHER1", OptionalAttachNodeString = "Attach_Major.006" },
			{ BuildingPart = "BUILDING_PART_MONASTICLIFE_FISHER1", OptionalAttachNodeString = "Attach_Major.007" },
		},
	},
})

-- Random
local poly1 = { -- y, x     Facing x in Blender: y increases going left, x increases going down
	{ 15, 0 },
	{ 17, -10 },
	{ 13, -17 },
	{ 1, -21 },
	{ -10, -19 },
	{ -16, -11 },
	{ -15, 0 },
	{ -16, 7 },
	{ -12, 22 },
	{ 4, 22.5 },
	{ 15, 13 },
}

mod:registerAsset({
    DataType = "BUILDING_PART",
    Id = "BUILDING_PART_MONASTICLIFE_POND1",
    Name = "BUILDING_PART_MONASTICLIFE_POND_NAME",
    ConstructorData = {
        DataType = "BUILDING_CONSTRUCTOR_RANDOM_PART",
        RandomPartList = {
            "BUILDING_PART_MONASTICLIFE_POND1_ASSEMBLAGE",
        },
        MiniatureConfig = {
            ClipUnderGround = true,
            GroupHeight = 0,
            CameraPosition = { 0, 0, 0 },
            OrientationOffset = 0,
            CameraPitchOffset = 25.0
        },
    },
    AssetBuildingFunction = "BUILDING_FUNCTION_MONASTICLIFE_FISH",
    BuildingZone = {
        ZoneEntryList = {
            {
                Polygon = poly1,
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = false },
            },
        },
    },
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD_COINS", Quantity = 150 },
        },
        UpkeepCost = {
            { Resource = "GOLD_COINS", Quantity = 30 }
        },
    },
})